"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createApplication = void 0;
const chalk_1 = __importDefault(require("chalk"));
const express_1 = __importDefault(require("express"));
const api_routes_1 = __importDefault(require("./endpoints/api/api.routes"));
const server_routes_1 = __importDefault(require("./endpoints/server/server.routes"));
const security_middleware_1 = require("./middleware/security.middleware");
const createApplication = (config) => {
    const app = (0, express_1.default)();
    app.all('*', (0, security_middleware_1.verifyRequest)(config));
    app.all('*', (req, res, next) => {
        console.log(chalk_1.default.blue(`[REQ] ${req.method} ${req.path}`));
        return next();
    });
    app.use(express_1.default.urlencoded({ extended: true }));
    app.use(express_1.default.json());
    app.use('/server', server_routes_1.default);
    app.use('/api', api_routes_1.default);
    app.all('/', (req, res) => {
        res.status(404).send('Binance local exchange is working!');
    });
    app.all('*', (req, res) => {
        const msg = `Route ${req.url} could not be found`;
        console.error(msg);
        res.status(404).send(msg);
    });
    app.disable('x-powered-by');
    return app;
};
exports.createApplication = createApplication;
