"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inversify_1 = require("inversify");
const configuration_service_1 = require("./services/configuration.service");
const kline_1 = require("./endpoints/websocket/eventHandlers/kline");
const userDataStream_1 = require("./endpoints/websocket/eventHandlers/userDataStream");
const websocketEventHandler_1 = require("./endpoints/websocket/websocketEventHandler");
const binance_service_1 = require("./services/binance.service");
const exchangeInfo_service_1 = require("./services/exchangeInfo.service");
const order_service_1 = require("./services/order.service");
const baseOrderMatcher_1 = require("./services/orderMatchers/baseOrderMatcher");
const limitOrder_matcher_1 = require("./services/orderMatchers/limitOrder.matcher");
const marketOrder_matcher_1 = require("./services/orderMatchers/marketOrder.matcher");
const orderMatching_service_1 = require("./services/orderMatching.service");
const exchangeInfo_query_1 = require("./store/exchangeInfo.query");
const exchangeInfo_store_1 = require("./store/exchangeInfo.store");
const order_query_1 = require("./store/order.query");
const order_store_1 = require("./store/order.store");
const userData_store_1 = require("./store/userData.store");
const container = new inversify_1.Container({
    skipBaseClassChecks: true,
    autoBindInjectable: true
});
container.bind(baseOrderMatcher_1.BaseOrderMatcher).to(marketOrder_matcher_1.MarketOrderMatcher);
container.bind(baseOrderMatcher_1.BaseOrderMatcher).to(limitOrder_matcher_1.LimitOrderMatcher);
container.bind(websocketEventHandler_1.WEBSOCKET_EVENT_HANDLER).to(kline_1.KlineEventHandler);
container.bind(websocketEventHandler_1.WEBSOCKET_EVENT_HANDLER).to(userDataStream_1.UserDataStreamEventHandler);
container.bind(configuration_service_1.ConfigurationService).toSelf().inSingletonScope();
container.bind(order_service_1.OrderService).toSelf().inSingletonScope();
container.bind(orderMatching_service_1.OrderMatchingService).toSelf().inSingletonScope();
container.bind(binance_service_1.BinanceService).toSelf().inSingletonScope();
container.bind(exchangeInfo_service_1.ExchangeInfoService).toSelf().inSingletonScope();
// Query
container.bind(order_query_1.OrderQuery).toSelf();
container.bind(exchangeInfo_query_1.ExchangeInfoQuery).toSelf();
// Stores
container.bind(order_store_1.OrderStore).toSelf().inSingletonScope();
container.bind(userData_store_1.UserDataStore).toSelf().inSingletonScope();
container.bind(exchangeInfo_store_1.ExchangeInfoStore).toSelf().inSingletonScope();
exports.default = container;
