"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderController = exports.OrderResponseType = void 0;
const inversify_1 = require("inversify");
const rxjs_1 = require("rxjs");
const order_service_1 = require("../../../services/order.service");
var OrderResponseType;
(function (OrderResponseType) {
    OrderResponseType["ACK"] = "ACK";
    OrderResponseType["FULL"] = "FULL";
    OrderResponseType["RESULT"] = "RESULT";
})(OrderResponseType = exports.OrderResponseType || (exports.OrderResponseType = {}));
let OrderController = class OrderController {
    constructor(orderService) {
        this.orderService = orderService;
    }
    determineResponseType(data) {
        let responseType;
        if (data.newOrderRespType) {
            responseType = data.newOrderRespType;
        }
        else {
            responseType = (['MARKET', 'LIMIT'].includes(data.type))
                ? OrderResponseType.FULL
                : OrderResponseType.ACK;
        }
        return responseType;
    }
    getACKResponse(data) {
        return {
            symbol: data.symbol,
            orderId: data.orderId,
            orderListId: data.orderListId,
            clientOrderId: data.clientOrderId,
            ...(data.transactTime ? { transactTime: data.transactTime } : {}),
        };
    }
    getRESULTResponse(data) {
        return {
            ...this.getACKResponse(data),
            price: data.price,
            origQty: data.origQty,
            executedQty: data.executedQty,
            cummulativeQuoteQty: data.cummulativeQuoteQty,
            status: data.status,
            timeInForce: data.timeInForce,
            type: data.type,
            side: data.side,
        };
    }
    getFULLResponse(data) {
        var _a;
        return {
            ...this.getRESULTResponse(data),
            fills: (_a = data.fills) !== null && _a !== void 0 ? _a : [],
        };
    }
    async postOrder(req, res) {
        const request = { ...req.body, ...req.query };
        const clientOrderId = await this.orderService.addFromSpotOrder(request);
        const confirmedOrder = await (0, rxjs_1.firstValueFrom)(this.orderService.getConfirmedOrder$(request, clientOrderId));
        const responseType = this.determineResponseType(request);
        if (responseType === OrderResponseType.ACK) {
            return res.json(this.getACKResponse(confirmedOrder));
        }
        else if (responseType === OrderResponseType.RESULT) {
            return res.json(this.getRESULTResponse(confirmedOrder));
        }
        else if (responseType === OrderResponseType.FULL) {
            return res.json(this.getFULLResponse(confirmedOrder));
        }
        else {
            throw new Error(`Unknown responseType: ${responseType}`);
        }
    }
};
OrderController = __decorate([
    (0, inversify_1.injectable)(),
    __param(0, (0, inversify_1.inject)(order_service_1.OrderService)),
    __metadata("design:paramtypes", [order_service_1.OrderService])
], OrderController);
exports.OrderController = OrderController;
