"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserDataStreamEventHandler = void 0;
const inversify_1 = require("inversify");
const rxjs_1 = require("rxjs");
const order_utils_1 = require("../../../utils/order.utils");
const exchangeInfo_service_1 = require("../../../services/exchangeInfo.service");
const order_query_1 = require("../../../store/order.query");
const userData_query_1 = require("../../../store/userData.query");
let UserDataStreamEventHandler = class UserDataStreamEventHandler {
    constructor(exchangeInfoService, userDataQuery, orderQuery) {
        this.exchangeInfoService = exchangeInfoService;
        this.userDataQuery = userDataQuery;
        this.orderQuery = orderQuery;
        this.filledOrderUpdates$ = this.orderQuery.getFilledOrderUpdates$().pipe((0, rxjs_1.withLatestFrom)(this.userDataQuery.isListening$()), (0, rxjs_1.filter)(([order, isListening]) => !!isListening && order.type != 'MARKET'), (0, rxjs_1.map)(([order]) => order));
        this.orderUpdateWithSymbol$ = this.filledOrderUpdates$.pipe((0, rxjs_1.mergeMap)((order) => (0, rxjs_1.combineLatest)([
            (0, rxjs_1.of)(order),
            this.exchangeInfoService.getSymbol(order.symbol)
        ])));
        this.orderUpdateWithSymbol$.subscribe(([order, symbol]) => {
            this.createExecutionReports(order, symbol).forEach((report) => {
                if (this.connection) {
                    this.connection.send(JSON.stringify(report));
                }
            });
        });
    }
    shouldHandle(request) {
        return (request === null || request === void 0 ? void 0 : request.url) === '/userDataStream';
    }
    async onMessage(connection, request) {
        if (!this.connection) {
            this.connection = connection;
        }
    }
    createExecutionReports(order, symbol) {
        var _a, _b;
        const f = (0, order_utils_1.createFixedFormatter)(symbol);
        let cumQty = 0;
        let cumQuoteQty = 0;
        return (_b = (_a = order.fills) === null || _a === void 0 ? void 0 : _a.map((fill) => {
            const quoteQty = fill.price * fill.qty;
            cumQuoteQty += quoteQty;
            cumQty += fill.qty;
            return {
                'e': 'executionReport',
                'E': new Date().getTime(),
                's': order.symbol,
                'c': order.clientOrderId,
                'S': order.side,
                'o': order.type,
                'f': order.timeInForce,
                'q': f(order.origQty, order_utils_1.FixedFormat.BAP),
                'p': f(order.price, order_utils_1.FixedFormat.BAP),
                'P': f(0, order_utils_1.FixedFormat.BAP),
                'F': f(0, order_utils_1.FixedFormat.BAP),
                'g': -1,
                'C': '',
                'x': 'TRADE',
                'X': order.status,
                'r': 'NONE',
                'i': order.orderId,
                'l': fill.qty,
                'z': f(cumQty, order_utils_1.FixedFormat.BAP),
                'L': fill.price,
                'n': f(fill.commission, order_utils_1.FixedFormat.QCP),
                'N': fill.commissionAsset,
                'T': order.transactTime,
                't': -1,
                'I': Math.round(Math.random() * 1000),
                'w': true,
                'm': false,
                'M': false,
                'O': order.time,
                'Z': f(cumQuoteQty, order_utils_1.FixedFormat.QAP),
                'Y': f(cumQty, order_utils_1.FixedFormat.QAP),
                'Q': f(order.cummulativeQuoteQty, order_utils_1.FixedFormat.QAP) // Quote Order Qty
            };
        })) !== null && _b !== void 0 ? _b : [];
    }
};
UserDataStreamEventHandler = __decorate([
    (0, inversify_1.injectable)(),
    __param(0, (0, inversify_1.inject)(exchangeInfo_service_1.ExchangeInfoService)),
    __param(1, (0, inversify_1.inject)(userData_query_1.UserDataQuery)),
    __param(2, (0, inversify_1.inject)(order_query_1.OrderQuery)),
    __metadata("design:paramtypes", [exchangeInfo_service_1.ExchangeInfoService,
        userData_query_1.UserDataQuery,
        order_query_1.OrderQuery])
], UserDataStreamEventHandler);
exports.UserDataStreamEventHandler = UserDataStreamEventHandler;
