#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const akita_1 = require("@datorama/akita");
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = require("commander");
require("reflect-metadata");
const package_json_1 = require("../package.json");
const application_1 = require("./application");
const configuration_service_1 = require("./services/configuration.service");
const container_1 = __importDefault(require("./container"));
const websocketServer_1 = __importDefault(require("./endpoints/websocket/websocketServer"));
(0, akita_1.akitaConfig)({ resettable: true });
commander_1.program
    .version(package_json_1.version)
    .addOption(new commander_1.Option('--I-KNOW-WHAT-I-AM-DOING', 'removes security warnings')
    .default(false)
    .env('I_KNOW_WHAT_I_AM_DOING'))
    .addOption(new commander_1.Option('-p, --port <number>', 'port number')
    .default(8000)
    .env('PORT'))
    .addOption(new commander_1.Option('-lt, --local-time', 'local time')
    .default(true)
    .env('LOCAL_TIME'))
    .addOption(new commander_1.Option('-lei, --local-exchange-info', 'local exchange info')
    .default(true)
    .env('LOCAL_EXCHANGE_INFO'))
    .addOption(new commander_1.Option('-fm, --fee-maker <number>', 'maker fee')
    .argParser(parseFloat)
    .default(0.001)
    .env('FEES_MAKER'))
    .addOption(new commander_1.Option('-ft, --fee-taker <number>', 'taker fee')
    .argParser(parseFloat)
    .default(0.001)
    .env('FEES_TAKER'))
    .parse(process.argv);
const configService = container_1.default.resolve(configuration_service_1.ConfigurationService);
configService.setApplicationConfig(commander_1.program.opts());
const websocketServer = container_1.default.resolve(websocketServer_1.default);
const server = websocketServer.createFromExpressApp((0, application_1.createApplication)(configService.getAll()));
//start our server
server.listen(configService.get('port'), () => {
    const address = server.address();
    const port = typeof address === 'string' ? address : address === null || address === void 0 ? void 0 : address.port;
    console.log(`Binance local exchange is listening on port: ${port}\n`);
    if (!configService.get('IKNOWWHATIAMDOING')) {
        const msg = `Don't send any API keys or signed signatures.
Binance local exchange doesn't need any of these to operate.`;
        console.warn(chalk_1.default.bgYellow(chalk_1.default.white(msg)));
    }
});
