"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyRequest = void 0;
const chalk_1 = __importDefault(require("chalk"));
const verifyRequest = (config) => {
    return (req, res, next) => {
        var _a, _b;
        if (config.IKNOWWHATIAMDOING)
            return next();
        if (!!req.headers['x-mbx-apikey']) {
            const warning = `YOU'RE CURRENTLY EXPOSING YOUR API KEY IN THE REQUEST HEADERS.
THIS COULD LEAD TO SEVERE SECURITY ISSUES AND POTENTIALLY STOLEN FUNDS,
IF YOUR SECRET API KEY HAS BEEN COMPROMISED!`;
            console.warn(chalk_1.default.bgYellow(chalk_1.default.black(warning)));
            process.exit(1);
        }
        if ((!((_a = req.query) === null || _a === void 0 ? void 0 : _a.signature) || !((_b = req.body) === null || _b === void 0 ? void 0 : _b.signature))) {
            const error = `A SIGNED SIGNATURE HAS BEEN FOUND IN THE REQUEST.
THIS IS A MAJOR SECURITY RISK AND COULD POTENTIALLY LEAD TO STOLEN FUNDS.
WE HIGHLY RECOMMEND TO STOP SENDING THE SIGNED SIGNATURE OR USE A FAKE API KEY AND SECRET COMBINATION.`;
            console.error(chalk_1.default.bgRed(chalk_1.default.white(error)));
            process.exit(1);
        }
    };
};
exports.verifyRequest = verifyRequest;
