"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderService = void 0;
const inversify_1 = require("inversify");
const rxjs_1 = require("rxjs");
const uuid_1 = require("uuid");
const order_utils_1 = require("../utils/order.utils");
const order_query_1 = require("../store/order.query");
const order_store_1 = require("../store/order.store");
const exchangeInfo_service_1 = require("./exchangeInfo.service");
const orderMatching_service_1 = require("./orderMatching.service");
let OrderService = class OrderService {
    constructor(orderStore, orderQuery, orderMatchingService, exchangeInfoService) {
        this.orderStore = orderStore;
        this.orderQuery = orderQuery;
        this.orderMatchingService = orderMatchingService;
        this.exchangeInfoService = exchangeInfoService;
    }
    async addFromSpotOrder(order) {
        let internalOrder = undefined;
        if ((0, order_utils_1.isLimitOrder)(order)) {
            internalOrder = this._getLimitOrder(order);
        }
        else if ((0, order_utils_1.isMarketOrderQuote)(order)) {
            internalOrder = this._getMarketOrderQuote(order);
        }
        else if ((0, order_utils_1.isMarketOrderBase)(order)) {
            internalOrder = this._getMarketOrderBase(order);
        }
        if (internalOrder == null)
            throw new Error(`Order type: "${order.type}" currently not supported`);
        this.orderStore.add(internalOrder);
        if ((0, order_utils_1.isMarketOrder)(order))
            await this.orderMatchingService.matchWithMarketPrice(order.symbol);
        return internalOrder.clientOrderId;
    }
    /**
     * Get all orders 'confirmed' orders that are newly stored in the Order store.
     * @param {NewOrderSpot} order
     * @param {string} clientOrderId
     * @returns {Observable<Order>}
     */
    getConfirmedOrder$(order, clientOrderId) {
        return this.orderQuery.selectEntity(clientOrderId).pipe((0, rxjs_1.filter)((o) => {
            return (o === null || o === void 0 ? void 0 : o.status) === (
            // Note: market orders are immediately filled.
            (order.type === 'MARKET') ? 'FILLED' : 'NEW');
        }), (0, rxjs_1.switchMap)(order => (0, rxjs_1.from)(this.exchangeInfoService.getSymbol(order.symbol)).pipe((0, rxjs_1.map)(symbol => [symbol, order]))), (0, rxjs_1.map)(([symbol, order]) => this._formatInternalOrder(order, symbol)));
    }
    _formatInternalOrder(order, symbol) {
        var _a, _b, _c, _d, _e, _f, _g;
        const f = (0, order_utils_1.createFixedFormatter)(symbol);
        const o = order;
        return {
            ...order,
            price: f((_a = o.price) !== null && _a !== void 0 ? _a : 0, order_utils_1.FixedFormat.BAP),
            origQty: f((_b = o.origQty) !== null && _b !== void 0 ? _b : 0, order_utils_1.FixedFormat.BAP),
            executedQty: f((_c = o.executedQty) !== null && _c !== void 0 ? _c : 0, order_utils_1.FixedFormat.BAP),
            cummulativeQuoteQty: f((_d = o.cummulativeQuoteQty) !== null && _d !== void 0 ? _d : 0, order_utils_1.FixedFormat.QAP),
            icebergQty: f((_e = order.icebergQty) !== null && _e !== void 0 ? _e : 0, order_utils_1.FixedFormat.BAP),
            stopPrice: f((_f = order.stopPrice) !== null && _f !== void 0 ? _f : 0, order_utils_1.FixedFormat.BAP),
            fills: ((_g = order.fills) !== null && _g !== void 0 ? _g : []).map(fill => ({
                ...fill,
                price: f(fill.price, order_utils_1.FixedFormat.BAP),
                qty: f(fill.qty, order_utils_1.FixedFormat.BAP),
                commission: f(fill.commission, order.side === 'BUY' ? order_utils_1.FixedFormat.BCP : order_utils_1.FixedFormat.QCP),
            }))
        };
    }
    _getBaseOrder(order) {
        var _a, _b;
        const clientOrderId = (_a = order.newClientOrderId) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
        return {
            symbol: order.symbol,
            orderId: this.orderStore.createNewOrderId(),
            orderListId: -1,
            clientOrderId,
            timeInForce: (_b = order.timeInForce) !== null && _b !== void 0 ? _b : 'GTC',
            type: order.type,
            side: order.side,
            updateTime: new Date().getTime(),
            time: new Date().getTime(),
            isWorking: true,
            status: 'NEW',
        };
    }
    _getLimitOrder(order) {
        const price = parseFloat(order.price);
        const qty = parseFloat(order.quantity);
        return {
            ...this._getBaseOrder(order),
            origQty: qty,
            price
        };
    }
    _getMarketOrderQuote(order) {
        return {
            ...this._getBaseOrder(order),
            cummulativeQuoteQty: parseFloat(order.quoteOrderQty),
            transactTime: new Date().getTime(),
        };
    }
    _getMarketOrderBase(order) {
        return {
            ...this._getBaseOrder(order),
            origQty: parseFloat(order.quantity),
            transactTime: new Date().getTime(),
        };
    }
};
OrderService = __decorate([
    (0, inversify_1.injectable)(),
    __param(0, (0, inversify_1.inject)(order_store_1.OrderStore)),
    __param(1, (0, inversify_1.inject)(order_query_1.OrderQuery)),
    __param(2, (0, inversify_1.inject)(orderMatching_service_1.OrderMatchingService)),
    __param(3, (0, inversify_1.inject)(exchangeInfo_service_1.ExchangeInfoService)),
    __metadata("design:paramtypes", [order_store_1.OrderStore,
        order_query_1.OrderQuery,
        orderMatching_service_1.OrderMatchingService,
        exchangeInfo_service_1.ExchangeInfoService])
], OrderService);
exports.OrderService = OrderService;
