"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderMatchingService = void 0;
const inversify_1 = require("inversify");
const rxjs_1 = require("rxjs");
const order_query_1 = require("../store/order.query");
const binance_service_1 = require("./binance.service");
const exchangeInfo_service_1 = require("./exchangeInfo.service");
const baseOrderMatcher_1 = require("./orderMatchers/baseOrderMatcher");
let OrderMatchingService = class OrderMatchingService {
    constructor(binanceService, orderQuery, exchangeInfoService, orderMatchers) {
        this.binanceService = binanceService;
        this.orderQuery = orderQuery;
        this.exchangeInfoService = exchangeInfoService;
        this.orderMatchers = orderMatchers;
    }
    async match(symbol, marketPrice) {
        const orders = await (0, rxjs_1.firstValueFrom)(this.orderQuery.getOpenOrdersForSymbol$(symbol));
        if (orders.length <= 0)
            return;
        const _symbol = await this.exchangeInfoService.getSymbol(symbol);
        orders.forEach((order) => {
            this.orderMatchers.forEach(matcher => {
                if (matcher.shouldMatch(order)) {
                    matcher.match(_symbol, order, marketPrice);
                }
            });
        });
    }
    async matchWithPrice(symbol, closePrice) {
        await this.match(symbol, closePrice);
    }
    async matchWithMarketPrice(symbol) {
        const result = await this.binanceService.getCurrentPrice(symbol);
        await this.match(symbol, result);
    }
};
OrderMatchingService = __decorate([
    (0, inversify_1.injectable)(),
    __param(0, (0, inversify_1.inject)(binance_service_1.BinanceService)),
    __param(1, (0, inversify_1.inject)(order_query_1.OrderQuery)),
    __param(2, (0, inversify_1.inject)(exchangeInfo_service_1.ExchangeInfoService)),
    __param(3, (0, inversify_1.multiInject)(baseOrderMatcher_1.BaseOrderMatcher)),
    __metadata("design:paramtypes", [binance_service_1.BinanceService,
        order_query_1.OrderQuery,
        exchangeInfo_service_1.ExchangeInfoService, Array])
], OrderMatchingService);
exports.OrderMatchingService = OrderMatchingService;
