"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isInternalLimitOrder = exports.isInternalMarketQuoteOrder = exports.isInternalMarketOrder = exports.getQuoteQuantity = exports.getBaseQuantity = void 0;
const getBaseQuantity = (order, price) => {
    if (!(0, exports.isInternalMarketQuoteOrder)(order)) {
        return order.origQty;
    }
    else if (price != null) {
        return order.cummulativeQuoteQty / price;
    }
    throw new Error('Could not determine base quantity when price is undefined');
};
exports.getBaseQuantity = getBaseQuantity;
const getQuoteQuantity = (order, price) => {
    if ((0, exports.isInternalMarketQuoteOrder)(order)) {
        return order.cummulativeQuoteQty;
    }
    else if (price != null) {
        return order.origQty * price;
    }
    throw new Error('Could not determine quote quantity when price is undefined');
};
exports.getQuoteQuantity = getQuoteQuantity;
const isInternalMarketOrder = (order) => 'origQty' in order && order.type === 'MARKET';
exports.isInternalMarketOrder = isInternalMarketOrder;
const isInternalMarketQuoteOrder = (order) => 'cummulativeQuoteQty' in order && order.type === 'MARKET';
exports.isInternalMarketQuoteOrder = isInternalMarketQuoteOrder;
const isInternalLimitOrder = (order) => order.type === 'LIMIT';
exports.isInternalLimitOrder = isInternalLimitOrder;
