"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMarketOrderQuote = exports.isMarketOrderBase = exports.isMarketOrder = exports.isLimitOrder = exports.createFixedFormatter = exports.FixedFormat = void 0;
var FixedFormat;
(function (FixedFormat) {
    FixedFormat[FixedFormat["BAP"] = 0] = "BAP";
    FixedFormat[FixedFormat["BCP"] = 1] = "BCP";
    FixedFormat[FixedFormat["QAP"] = 2] = "QAP";
    FixedFormat[FixedFormat["QCP"] = 3] = "QCP";
    FixedFormat[FixedFormat["QP"] = 4] = "QP"; // quotePrecision
})(FixedFormat = exports.FixedFormat || (exports.FixedFormat = {}));
const createFixedFormatter = (symbol) => (value, format) => {
    switch (format) {
        case FixedFormat.BAP:
            return value.toFixed(symbol.baseAssetPrecision);
        case FixedFormat.BCP:
            return value.toFixed(symbol.baseCommissionPrecision);
        case FixedFormat.QAP:
            return value.toFixed(symbol.quoteAssetPrecision);
        case FixedFormat.QCP:
            return value.toFixed(symbol.quoteCommissionPrecision);
        case FixedFormat.QP:
            return value.toFixed(symbol.quotePrecision);
        default:
            throw new Error('Invalid format given');
    }
};
exports.createFixedFormatter = createFixedFormatter;
const isLimitOrder = (order) => order.type === 'LIMIT';
exports.isLimitOrder = isLimitOrder;
const isMarketOrder = (order) => order.type === 'MARKET';
exports.isMarketOrder = isMarketOrder;
const isMarketOrderBase = (order) => 'quantity' in order;
exports.isMarketOrderBase = isMarketOrderBase;
const isMarketOrderQuote = (order) => 'quoteOrderQty' in order;
exports.isMarketOrderQuote = isMarketOrderQuote;
